.. AUTO-GENERATED FILE -- DO NOT EDIT!

pygam
=====

Module: :mod:`pygam`
--------------------
.. automodule:: ISLP.pygam

.. currentmodule:: ISLP.pygam

Functions
---------


.. autofunction:: ISLP.pygam.anova


.. autofunction:: ISLP.pygam.approx_lam


.. autofunction:: ISLP.pygam.degrees_of_freedom


.. autofunction:: ISLP.pygam.plot

